==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/ComponentsFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import com.fasterxml.jackson.databind.JsonNode;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ComponentsFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent<A>{
  public ComponentsFluentImpl() {
  }
  public ComponentsFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1.Components instance) {
    this.withLabelSelector(instance.getLabelSelector()); 
    this.withRefs(instance.getRefs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder labelSelector;
  private java.util.List<com.fasterxml.jackson.databind.JsonNode> refs = new java.util.ArrayList<com.fasterxml.jackson.databind.JsonNode>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildLabelSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getLabelSelector() {
    return this.labelSelector!=null?this.labelSelector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildLabelSelector() {
    return this.labelSelector!=null?this.labelSelector.build():null;
  }
  public A withLabelSelector(io.fabric8.kubernetes.api.model.LabelSelector labelSelector) {
    _visitables.get("labelSelector").remove(this.labelSelector);
    if (labelSelector!=null){ this.labelSelector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(labelSelector); _visitables.get("labelSelector").add(this.labelSelector);} return (A) this;
  }
  public java.lang.Boolean hasLabelSelector() {
    return this.labelSelector != null;
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<A> withNewLabelSelector() {
    return new io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluentImpl.LabelSelectorNestedImpl();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<A> withNewLabelSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluentImpl.LabelSelectorNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<A> editLabelSelector() {
    return withNewLabelSelectorLike(getLabelSelector());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<A> editOrNewLabelSelector() {
    return withNewLabelSelectorLike(getLabelSelector() != null ? getLabelSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<A> editOrNewLabelSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewLabelSelectorLike(getLabelSelector() != null ? getLabelSelector(): item);
  }
  public A addToRefs(java.lang.Integer index,com.fasterxml.jackson.databind.JsonNode item) {
    if (this.refs == null) {this.refs = new java.util.ArrayList<com.fasterxml.jackson.databind.JsonNode>();}
    this.refs.add(index, item);
    return (A)this;
  }
  public A setToRefs(java.lang.Integer index,com.fasterxml.jackson.databind.JsonNode item) {
    if (this.refs == null) {this.refs = new java.util.ArrayList<com.fasterxml.jackson.databind.JsonNode>();}
    this.refs.set(index, item); return (A)this;
  }
  public A addToRefs(com.fasterxml.jackson.databind.JsonNode... items) {
    if (this.refs == null) {this.refs = new java.util.ArrayList<com.fasterxml.jackson.databind.JsonNode>();}
    for (com.fasterxml.jackson.databind.JsonNode item : items) {this.refs.add(item);} return (A)this;
  }
  public A addAllToRefs(java.util.Collection<com.fasterxml.jackson.databind.JsonNode> items) {
    if (this.refs == null) {this.refs = new java.util.ArrayList<com.fasterxml.jackson.databind.JsonNode>();}
    for (com.fasterxml.jackson.databind.JsonNode item : items) {this.refs.add(item);} return (A)this;
  }
  public A removeFromRefs(com.fasterxml.jackson.databind.JsonNode... items) {
    for (com.fasterxml.jackson.databind.JsonNode item : items) {if (this.refs!= null){ this.refs.remove(item);}} return (A)this;
  }
  public A removeAllFromRefs(java.util.Collection<com.fasterxml.jackson.databind.JsonNode> items) {
    for (com.fasterxml.jackson.databind.JsonNode item : items) {if (this.refs!= null){ this.refs.remove(item);}} return (A)this;
  }
  public java.util.List<com.fasterxml.jackson.databind.JsonNode> getRefs() {
    return this.refs;
  }
  public com.fasterxml.jackson.databind.JsonNode getRef(java.lang.Integer index) {
    return this.refs.get(index);
  }
  public com.fasterxml.jackson.databind.JsonNode getFirstRef() {
    return this.refs.get(0);
  }
  public com.fasterxml.jackson.databind.JsonNode getLastRef() {
    return this.refs.get(refs.size() - 1);
  }
  public com.fasterxml.jackson.databind.JsonNode getMatchingRef(java.util.function.Predicate<com.fasterxml.jackson.databind.JsonNode> predicate) {
    for (com.fasterxml.jackson.databind.JsonNode item: refs) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingRef(java.util.function.Predicate<com.fasterxml.jackson.databind.JsonNode> predicate) {
    for (com.fasterxml.jackson.databind.JsonNode item: refs) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withRefs(java.util.List<com.fasterxml.jackson.databind.JsonNode> refs) {
    if (refs != null) {this.refs = new java.util.ArrayList<com.fasterxml.jackson.databind.JsonNode>(); for (com.fasterxml.jackson.databind.JsonNode item : refs){this.addToRefs(item);}} else { this.refs = null;} return (A) this;
  }
  public A withRefs(com.fasterxml.jackson.databind.JsonNode... refs) {
    if (this.refs != null) {this.refs.clear();}
    if (refs != null) {for (com.fasterxml.jackson.databind.JsonNode item :refs){ this.addToRefs(item);}} return (A) this;
  }
  public java.lang.Boolean hasRefs() {
    return refs != null && !refs.isEmpty();
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ComponentsFluentImpl that = (ComponentsFluentImpl) o;
    if (labelSelector != null ? !labelSelector.equals(that.labelSelector) :that.labelSelector != null) return false;
    if (refs != null ? !refs.equals(that.refs) :that.refs != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(labelSelector,  refs,  additionalProperties,  super.hashCode());
  }
  public class LabelSelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    LabelSelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    LabelSelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) ComponentsFluentImpl.this.withLabelSelector(builder.build());
    }
    public N endLabelSelector() {
      return and();
    }
    
  }
  
}

==> openshift-model-operatorhub-5.12.4-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/ComponentsFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import com.fasterxml.jackson.databind.JsonNode;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ComponentsFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent<A>{
  public ComponentsFluentImpl() {
  }
  public ComponentsFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1.Components instance) {
    this.withLabelSelector(instance.getLabelSelector()); 
    this.withRefs(instance.getRefs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder labelSelector;
  private java.util.List<com.fasterxml.jackson.databind.JsonNode> refs = new java.util.ArrayList<com.fasterxml.jackson.databind.JsonNode>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildLabelSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getLabelSelector() {
    return this.labelSelector!=null?this.labelSelector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildLabelSelector() {
    return this.labelSelector!=null?this.labelSelector.build():null;
  }
  public A withLabelSelector(io.fabric8.kubernetes.api.model.LabelSelector labelSelector) {
    _visitables.get("labelSelector").remove(this.labelSelector);
    if (labelSelector!=null){ this.labelSelector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(labelSelector); _visitables.get("labelSelector").add(this.labelSelector);} return (A) this;
  }
  public java.lang.Boolean hasLabelSelector() {
    return this.labelSelector != null;
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<A> withNewLabelSelector() {
    return new io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluentImpl.LabelSelectorNestedImpl();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<A> withNewLabelSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluentImpl.LabelSelectorNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<A> editLabelSelector() {
    return withNewLabelSelectorLike(getLabelSelector());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<A> editOrNewLabelSelector() {
    return withNewLabelSelectorLike(getLabelSelector() != null ? getLabelSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<A> editOrNewLabelSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewLabelSelectorLike(getLabelSelector() != null ? getLabelSelector(): item);
  }
  public A addToRefs(java.lang.Integer index,com.fasterxml.jackson.databind.JsonNode item) {
    if (this.refs == null) {this.refs = new java.util.ArrayList<com.fasterxml.jackson.databind.JsonNode>();}
    this.refs.add(index, item);
    return (A)this;
  }
  public A setToRefs(java.lang.Integer index,com.fasterxml.jackson.databind.JsonNode item) {
    if (this.refs == null) {this.refs = new java.util.ArrayList<com.fasterxml.jackson.databind.JsonNode>();}
    this.refs.set(index, item); return (A)this;
  }
  public A addToRefs(com.fasterxml.jackson.databind.JsonNode... items) {
    if (this.refs == null) {this.refs = new java.util.ArrayList<com.fasterxml.jackson.databind.JsonNode>();}
    for (com.fasterxml.jackson.databind.JsonNode item : items) {this.refs.add(item);} return (A)this;
  }
  public A addAllToRefs(java.util.Collection<com.fasterxml.jackson.databind.JsonNode> items) {
    if (this.refs == null) {this.refs = new java.util.ArrayList<com.fasterxml.jackson.databind.JsonNode>();}
    for (com.fasterxml.jackson.databind.JsonNode item : items) {this.refs.add(item);} return (A)this;
  }
  public A removeFromRefs(com.fasterxml.jackson.databind.JsonNode... items) {
    for (com.fasterxml.jackson.databind.JsonNode item : items) {if (this.refs!= null){ this.refs.remove(item);}} return (A)this;
  }
  public A removeAllFromRefs(java.util.Collection<com.fasterxml.jackson.databind.JsonNode> items) {
    for (com.fasterxml.jackson.databind.JsonNode item : items) {if (this.refs!= null){ this.refs.remove(item);}} return (A)this;
  }
  public java.util.List<com.fasterxml.jackson.databind.JsonNode> getRefs() {
    return this.refs;
  }
  public com.fasterxml.jackson.databind.JsonNode getRef(java.lang.Integer index) {
    return this.refs.get(index);
  }
  public com.fasterxml.jackson.databind.JsonNode getFirstRef() {
    return this.refs.get(0);
  }
  public com.fasterxml.jackson.databind.JsonNode getLastRef() {
    return this.refs.get(refs.size() - 1);
  }
  public com.fasterxml.jackson.databind.JsonNode getMatchingRef(java.util.function.Predicate<com.fasterxml.jackson.databind.JsonNode> predicate) {
    for (com.fasterxml.jackson.databind.JsonNode item: refs) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingRef(java.util.function.Predicate<com.fasterxml.jackson.databind.JsonNode> predicate) {
    for (com.fasterxml.jackson.databind.JsonNode item: refs) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withRefs(java.util.List<com.fasterxml.jackson.databind.JsonNode> refs) {
    if (refs != null) {this.refs = new java.util.ArrayList(); for (com.fasterxml.jackson.databind.JsonNode item : refs){this.addToRefs(item);}} else { this.refs = null;} return (A) this;
  }
  public A withRefs(com.fasterxml.jackson.databind.JsonNode... refs) {
    if (this.refs != null) {this.refs.clear();}
    if (refs != null) {for (com.fasterxml.jackson.databind.JsonNode item :refs){ this.addToRefs(item);}} return (A) this;
  }
  public java.lang.Boolean hasRefs() {
    return refs != null && !refs.isEmpty();
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ComponentsFluentImpl that = (ComponentsFluentImpl) o;
    if (labelSelector != null ? !labelSelector.equals(that.labelSelector) :that.labelSelector != null) return false;
    if (refs != null ? !refs.equals(that.refs) :that.refs != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(labelSelector,  refs,  additionalProperties,  super.hashCode());
  }
  public class LabelSelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluent.LabelSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    LabelSelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    LabelSelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) ComponentsFluentImpl.this.withLabelSelector(builder.build());
    }
    public N endLabelSelector() {
      return and();
    }
    
  }
  
}
